# ts-scan Roadmap

In our current planning, we prioritise the extension with additional development environments / languages.  In the first place our plan is to add our further existing scanners, so that we can get rid of them and focus on the development of this solution. 

The next priorities are :

1. C/C++ via Cmake (Q2/25)
2. Rust via Cargo (Q2/25)
3. Go  (Q3/25)
4. php via Composer (Q4/25)

If you prefer a change in priorities, feel free to reach out. we are flexible to discuss. Or just take it into your hands. We love contributions. See the [Contribution Guide](/ts-scan/adding.md) for more information.

On the other hand we plan to extend the analysis with adding call graph analysis. Primary use case for this sort of analysis result is to better support CVE handling. However, we currently focus on getting the CRA readiness done. In our next platform release CSAF reporting, document handling and automated VEX-generation will be in the focus. This wil charge the damand for call graph analysis...

Feel invited to [reach out](https://www.trustsource.io/contact) and discuss your priorities. 

